@@ -1,14 +1,19 @@
 import os
 import tempfile
 
-def viminput(content=None):
+def textinput(content=None, editor=None):
+    if not editor:
+        editor = os.environ.get('EDITOR','vim')
     tf = tempfile.NamedTemporaryFile()
     if content:
         tf.write(content)
         tf.seek(0)
-    os.system("vim %s"%tf.name)
+    os.system("%s %s"%(editor, tf.name))
     data = tf.read()
     tf.close()
-    if data[-1] == "\n":
+    if len(data) > 0 and data[-1] == "\n":
         data = data[:-1]
-    return data
\ No newline at end of file
+    return data
+
+def viminput(content=None):
+    return textinput(content, "vim")
